#
# spec file for package python-CommonMark
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oldpython python
Name:           python-CommonMark
Version:        0.8.1
Release:        2.1
Summary:        Python parser for the CommonMark Markdown spec
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/rtfd/CommonMark-py
Source:         https://files.pythonhosted.org/packages/source/c/commonmark/commonmark-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-future
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
Provides:       python-commonmark = %{version}
Obsoletes:      python-commonmark < %{version}
BuildArch:      noarch
%ifpython2
Requires:       python-future
Obsoletes:      %{oldpython}-commonmark < %{version}
Provides:       %{oldpython}-commonmark = %{version}
%endif
%ifpython3
Conflicts:      cmark
Provides:       cmark-python
Obsoletes:      cmark-python
%endif
%python_subpackages

%description
Pure Python port of jgm's stmd.js, a Markdown parser and renderer for the
CommonMark specification, using only native modules.

%prep
%setup -q -n commonmark-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} $python commonmark/tests/unit_tests.py
# On python2 we error out on unicode issues
PYTHONPATH=%{buildroot}%{python3_sitelib} python3 setup.py test

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/*
%python3_only %{_bindir}/cmark

%changelog
* Tue Mar  5 2019 tchvatal@suse.com
- Update to 0.8.1:
  * Added the Node.normalize() method. (from @lez)
  * Renamed package name to commonmark for PEP8 compliance. You can now do import commonmark as well as import CommonMark. Closes #60
  * Added testing on Python 3.7.
  * Removed CommonMark symlink. So, as of this version, you need to replace all instances of CommonMark with commonmark in your code.
- Remove the not-needed subpackages
- Run the tests
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Sat Apr  7 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 0.7.5:
  * Fixed smart dashes bug in Python 3 (from @alvra)
* Mon Oct 30 2017 arun@gmx.de
- update to version 0.7.4:
  * The CommonMark spec has been updated to 0.28.
* Wed Jun 21 2017 dimstar@opensuse.org
- Fix typo in Requires (pyython3 -> python3).
* Fri Jun  9 2017 jengelh@inai.de
- A roadmap does not belong into the description.
- Resolve typographicly wrong apostrophe.
* Sat May  6 2017 toddrme2178@gmail.com
- Fix Provides/Obsoletes.
* Fri Apr 21 2017 toddrme2178@gmail.com
- Split "cmark" executable into own package to avoid conflicts with
  the cmark C reference implementation.
* Mon Apr  3 2017 toddrme2178@gmail.com
- Update to 0.7.3
  * The CommonMark spec has been updated to 0.27.
- Update to 0.7.2
  * Removed outdated files from distributed packages, reported by @hyperknot
- Update to 0.7.1
  * Updated CommonMark spec to 0.26.
  * Fixed JSON output invoked by `cmark -aj somefile.md`, reported by @rplCloud
  * Fixed a bug with `dumpAST()` on ordered lists, from @rflynn
- Update to 0.7.0
  * The `cmark.py` script is now just called `cmark`.
  * Fixed a bug where the `cmark.py` script contained a bogus path, reported
    by @yuhui-lin.
  * Fixed a bug where a TypeError could occur, reported by @civalin.
- Update to 0.6.4
  * The CommonMark spec has been updated to 0.25.
  * The HtmlRenderer has been refactored based on upstream changes in commonmark.js.
  * Python 2 fixes from @eric-wieser
  * Contributions from @funkybob and @hyperknot
- Update to 0.6.3
  * CommonMark-py now supports Python 2.6.
  * The CommonMark spec has been updated to 0.24.
- Update to 0.6.2
  * Fixed a UnicodeEncodeError when parsing unicode entities on
    Python 2. As a result, CommonMark-py now relies on the "future"
    module in Python 2, as documented in setup.py. This can be found on
    pypi: https://pypi.python.org/pypi/future
- Update to 0.6.1
  * Fixed an IndexError exception that occurred when input string
    was empty.
- Update to 0.6.0
  * CommonMark-py now complies to the 0.23 CommonMark spec
    http://spec.commonmark.org/0.23/
  * The ExtensionBlock has been removed in this release, since
    the parser has been rewritten.
  * Added a compatibility fix for Python 2.6, but this version
    of Python still isn't really supported.
  * `HTMLRenderer` has been renamed to `HtmlRenderer`.
  * `DocParser` has been renamed to `Parser`.
- Update to 0.5.5
  * Random bug fixes
  * Internal code structure changes
  * Compatibility fixes for Python 3
- Initial singlespec version
* Sun May  8 2016 arun@gmx.de
- specfile:
  * changed to https for source url
  * updated source url to files.pythonhosted.org
* Wed Dec  9 2015 bruno@ioda-net.ch
- Initial packaging on obs
